Struct plex_api::library::Part

source ·
pub struct Part<'a, M: MediaItem> {
    pub media_index: usize,
    pub part_index: usize,
    /* private fields */
}
One part of a Media.

Fields

media_index: usizepart_index: usize

Implementations

source

impl<'a, M: MediaItem> Part<'a, M>

source

pub fn len(&self) -> Option<u64>

The length of this file on disk in bytes.

source

pub async fn download<W, R>(&self, writer: W, range: R) -> Resultwhere W: AsyncWrite + Unpin, R: RangeBounds<u64>,

Downloads the original media file for this part writing the data into the provided writer. A range of bytes within the file can be requested allowing for resumable transfers.

Configured timeout value will be ignored during downloading.

source

pub fn metadata(&self) -> &PartMetadata

The internal metadata for the media.

source

impl<'a, M: MediaItemWithTranscoding> Part<'a, M>

source

pub async fn create_download_session( &self, options: M::Options ) -> Result<TranscodeSession>

Starts an offline transcode using the provided options.

The server may refuse to transcode if the options suggest that the original media file can be played back directly.

Can’t be called on media other than Movie, Episode or Track.

source

pub async fn create_streaming_session( &self, protocol: Protocol, options: M::Options ) -> Result<TranscodeSession>

Starts a streaming transcode using of the given media part using the streaming protocol and provided options.

Can’t be called on media other than Movie, Episode or Track.