MediaItem

Trait MediaItem 

pub trait MediaItem: MetadataItem + Sized {
    // Provided method
    fn media(&self) -> Vec<Media<'_, Self>> { ... }
}
Represents some playable media. In Plex each playable item can be available in a number of different formats which in turn can be made up of a number of different parts.

Provided Methods

fn media(&self) -> Vec<Media<'_, Self>>

The different media formats that this item is available in.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors