pub struct Friend {Show 15 fields
pub id: u64,
pub uuid: String,
pub title: String,
pub username: Option<String>,
pub email: Option<String>,
pub restricted: bool,
pub restriction_profile: Option<RestrictionProfile>,
pub friendly_name: Option<String>,
pub friendship_created_at: Option<OffsetDateTime>,
pub thumb: Uri,
pub home: bool,
pub status: Option<InviteStatus>,
pub sharing_settings: Option<Settings>,
pub shared_servers: Vec<SharedServer>,
pub shared_sources: Vec<String>,
/* private fields */
}Fields
id: u64The global Plex.tv ID of the friend
uuid: StringPlex.tv user’s uuid ??
title: StringHow the user should be displayed in the interface. Seems to be generated on the backed from either username or friendly_name.
username: Option<String>Non-managed user’s username
email: Option<String>Non-managed user’s email
restricted: boolIs it a managed user?
restriction_profile: Option<RestrictionProfile>Restrictions on the managed user (if any)
friendly_name: Option<String>Managed user’s username
friendship_created_at: Option<OffsetDateTime>thumb: UriUser’s avatar picture URL
home: boolDoes the user has access to Plex Home?
status: Option<InviteStatus>Status of the friendship
sharing_settings: Option<Settings>Server sharing preferences
List of the shared servers
No idea what this is
Implementations