Module plex_api::transcode

source ·
Support for transcoding media files into lower quality versions.

Transcoding comes in two forms:

  • Streaming allows for real-time playback of the media using streaming protocols such as HTTP Live Streaming and Dynamic Adaptive Streaming over HTTP.
  • Offline transcoding (the mobile downloads feature) requests that the server converts the file in the background allowing it to be downloaded later.

This feature should be considered quite experimental, lots of the API calls are derived from inspection and guesswork.

Structs

Enums

Traits