Struct plex_api::transcode::ArtTranscodeOptions
source · pub struct ArtTranscodeOptions {
pub upscale: bool,
pub min_size: bool,
}Fields
upscale: boolIf true and the source image is smaller than that requested it will be upscaled.
min_size: boolSets whether the requested size is the minimum size desired or the maximum.