pub struct VideoTranscodeOptions {
    pub bitrate: u32,
    pub width: u32,
    pub height: u32,
    pub audio_boost: Option<u8>,
    pub burn_subtitles: bool,
    pub containers: Vec<ContainerFormat>,
    pub video_codecs: Vec<VideoCodec>,
    pub video_limitations: Vec<Limitation<VideoCodec, VideoSetting>>,
    pub audio_codecs: Vec<AudioCodec>,
    pub audio_limitations: Vec<Limitation<AudioCodec, AudioSetting>>,
}
Defines the media formats suitable for transcoding video. The server uses these settings to choose a format to transcode to.

The server is not very clever at choosing codecs that work for a given container format. It is safest to only list codecs and containers that work together.

Note that the server maintains default transcode profiles for many devices which will alter the supported transcode targets. By default for instance if the server thinks you are an Android client it will only offer stereo audio in videos. You can see these profiles in Resources/Profiles of the media server install directory. Individual settings in the profile can be overridden via the API however if you want to be sure of a clean slate use a generic client.

Fields

bitrate: u32

Maximum bitrate in kbps.

width: u32

Maximum video width.

height: u32

Maximum video height.

audio_boost: Option<u8>

Audio gain from 0 to 100.

burn_subtitles: bool

Whether to burn the subtitles into the video.

containers: Vec<ContainerFormat>

Supported media container formats. Ignored for streaming transcodes.

video_codecs: Vec<VideoCodec>

Supported video codecs.

video_limitations: Vec<Limitation<VideoCodec, VideoSetting>>

Limitations to constraint video transcoding options.

audio_codecs: Vec<AudioCodec>

Supported audio codecs.

audio_limitations: Vec<Limitation<AudioCodec, AudioSetting>>

Limitations to constraint audio transcoding options.