pub enum Event {
Show 13 variants
LibraryOnDeck,
LibraryNew,
MediaPause,
MediaPlay,
MediaRate,
MediaResume,
MediaScrobble,
MediaStop,
AdminDatabaseBackup,
AdminDatabaseCorrupted,
DeviceNew,
PlaybackStarted,
Unknown,
}Expand description
Event type as described in the Plex documentation.
Variants
LibraryOnDeck
A new item is added that appears in the user’s On Deck. A poster is also attached to this event.
LibraryNew
A new item is added to a library to which the user has access. A poster is also attached to this event.
MediaPause
Media playback pauses.
MediaPlay
Media starts playing. An appropriate poster is attached.
MediaRate
Media is rated. A poster is also attached to this event.
MediaResume
Media playback resumes.
MediaScrobble
Media is viewed (played past the 90% mark).
MediaStop
Media playback stops.
AdminDatabaseBackup
A database backup is completed successfully via Scheduled Tasks.
AdminDatabaseCorrupted
Corruption is detected in the server database.
DeviceNew
A device accesses the owner’s server for any reason, which may come from background connection testing and doesn’t necessarily indicate active browsing or playback.
PlaybackStarted
Playback is started by a shared user for the server. A poster is also attached to this event.
Unknown