pub trait MediaItem: MetadataItem + Sized {
// Provided method
fn media(&self) -> Vec<Media<'_, Self>> { ... }
}Expand description
Represents some playable media. In Plex each playable item can be available in a number of different formats which in turn can be made up of a number of different parts.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".